==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/sax/Namespaces.h <==
// class gnu.xml.libxmlj.sax.Namespaces

// class file dependencies
// @dep_class f15b0365d8fb067f gnu_xml_libxmlj_sax_Namespaces
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_sax_Namespaces_H_
#define _JC_gnu_xml_libxmlj_sax_Namespaces_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs	_jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$refs	_jc_gnu_xml_libxmlj_sax_Namespaces$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs	_jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$object	_jc_gnu_xml_libxmlj_sax_Namespaces$object;

typedef const struct _jc_gnu_xml_libxmlj_sax_Namespaces$vmethods	_jc_gnu_xml_libxmlj_sax_Namespaces$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtable	_jc_gnu_xml_libxmlj_sax_Namespaces$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtype	_jc_gnu_xml_libxmlj_sax_Namespaces$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_libxmlj_sax_Namespaces$method$currentPrefixes$151ce07b9c8647d5(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$define$85e439c41adbbc25(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_sax_Namespaces$method$getURI$e7ae664b038c4dc4(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$pop$73381a92c26c579b(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$push$e8891ab835b0da1a(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$currentPrefixes$151ce07b9c8647d5;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$define$85e439c41adbbc25;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$getURI$e7ae664b038c4dc4;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$pop$73381a92c26c579b;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$push$e8891ab835b0da1a;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_Namespaces$vmethods {
	struct _jc_object	*(*currentPrefixes$151ce07b9c8647d5)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);
	void	(*define$85e439c41adbbc25)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*getURI$e7ae664b038c4dc4)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *);
	void	(*pop$73381a92c26c579b)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);
	void	(*push$e8891ab835b0da1a)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_sax_Namespaces$vmethods	gnu_xml_libxmlj_sax_Namespaces;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_Namespaces$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs {
	struct _jc_java_util_ArrayList$object	*stack;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$refs {
    _jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs	gnu_xml_libxmlj_sax_Namespaces;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs	gnu_xml_libxmlj_sax_Namespaces;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_Namespaces$object {
	_jc_gnu_xml_libxmlj_sax_Namespaces$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_Namespaces$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_Namespaces$vtype _jc_gnu_xml_libxmlj_sax_Namespaces$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_Namespaces, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_Namespaces$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_Namespaces_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/sax/Namespaces.h <==
// class gnu.xml.libxmlj.sax.Namespaces

// class file dependencies
// @dep_class f15b0365d8fb067f gnu_xml_libxmlj_sax_Namespaces
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_sax_Namespaces_H_
#define _JC_gnu_xml_libxmlj_sax_Namespaces_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs	_jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$refs	_jc_gnu_xml_libxmlj_sax_Namespaces$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs	_jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_Namespaces$object	_jc_gnu_xml_libxmlj_sax_Namespaces$object;

typedef const struct _jc_gnu_xml_libxmlj_sax_Namespaces$vmethods	_jc_gnu_xml_libxmlj_sax_Namespaces$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtable	_jc_gnu_xml_libxmlj_sax_Namespaces$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtype	_jc_gnu_xml_libxmlj_sax_Namespaces$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_libxmlj_sax_Namespaces$method$currentPrefixes$151ce07b9c8647d5(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$define$85e439c41adbbc25(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_sax_Namespaces$method$getURI$e7ae664b038c4dc4(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$pop$73381a92c26c579b(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$push$e8891ab835b0da1a(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_sax_Namespaces$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$currentPrefixes$151ce07b9c8647d5;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$define$85e439c41adbbc25;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$getURI$e7ae664b038c4dc4;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$pop$73381a92c26c579b;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$push$e8891ab835b0da1a;
extern _jc_method _jc_gnu_xml_libxmlj_sax_Namespaces$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_Namespaces$vmethods {
	struct _jc_object	*(*currentPrefixes$151ce07b9c8647d5)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;
	void	(*define$85e439c41adbbc25)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getURI$e7ae664b038c4dc4)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*pop$73381a92c26c579b)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;
	void	(*push$e8891ab835b0da1a)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_Namespaces$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_sax_Namespaces$vmethods	gnu_xml_libxmlj_sax_Namespaces;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_Namespaces$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_Namespaces$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs {
	struct _jc_java_util_ArrayList$object	*stack;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$refs {
    _jc_gnu_xml_libxmlj_sax_Namespaces$sub_refs	gnu_xml_libxmlj_sax_Namespaces;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_sax_Namespaces$sub_nonrefs	gnu_xml_libxmlj_sax_Namespaces;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_Namespaces$object {
	_jc_gnu_xml_libxmlj_sax_Namespaces$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_Namespaces$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_Namespaces$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_Namespaces$vtype _jc_gnu_xml_libxmlj_sax_Namespaces$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_Namespaces, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_Namespaces$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_Namespaces_H_ */
